@@ -3,6 +3,7 @@ import importlib
 import inspect
 import re
 from collections import defaultdict
+from datetime import datetime
 from enum import Enum, auto
 from inspect import getfile
 from pathlib import Path
@@ -120,6 +121,7 @@ class ModelConfig:
         labels (Labels): Labels that can be used for data catalog and resource selection
         materialized (amora.models.MaterializationTypes): The materialization configuration: `view`, `table`, `ephemeral`. Default: `view`
         partition_by (Optional[PartitionConfig]): BigQuery supports the use of a [partition by](https://cloud.google.com/bigquery/docs/partitioned-tables) clause to easily partition a table by a column or expression. This option can help decrease latency and cost when querying large tables.
+        hours_to_expire (Optional[int]): Bigquery supports setting an expiration time for a table. (https://cloud.google.com/bigquery/docs/managing-tables?hl=pt-br#updating_a_tables_expiration_time). Having this option can help us free up more space.
     """
 
     description: str = "Undocumented! Generated by Amora Data Build Tool 💚"
@@ -128,6 +130,7 @@ class ModelConfig:
     cluster_by: Optional[List[str]] = None
     labels: Labels = dataclasses.field(default_factory=set)
     owner: Optional[Owner] = None
+    hours_to_expire: Optional[int] = None
 
     @property
     def labels_dict(self) -> Dict[str, str]:
